#
# spec file for package python-python-docs-theme
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-docs-theme
Version:        2024.1
Release:        1.3
Summary:        The Sphinx theme for the CPython docs and related projects
License:        Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/python/python-docs-theme
Source:         https://files.pythonhosted.org/packages/source/p/python-docs-theme/python_docs_theme-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
The Sphinx theme for the CPython docs and related projects

%prep
%setup -q -n python_docs_theme-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/python_docs_theme
%{python_sitelib}/python_docs_theme-%{version}*-info

%changelog
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1:
  * Underline links for readability and a11y
  * Add `hosted_on` variable for a link in the footer
  * Consistently reference `theme_root_icon`
  * Dark mode: fix contrast of footer highlight
* Sat Dec  9 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.9:
  * Focus search box when pressing slash
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.7:
  * Fix compatability with Sphinx 7.1
  * Enable the slash keypress to focus the search field
  * Sphinx 6.2 fix: add ``nav.contents`` where ``div.topic`` is
    used
  * Dark mode: fix contrast for C++ specific styling (#133)
  * Don't let long code literals extend beyond the right side of
    the screen
  * Test with Python 3.12
  * Add a dark theme.
  * Fix: Remove searchbox id from form.
  * Update ``python-docs-theme`` to work with Sphinx 5 & 6.
  * Override font for ``.sig`` for consistency with other code
    blocks.
  * Dark mode: add class to invert image brightness.
  * Skip cache-busting for old Sphinx
  * Fix problem with monospace rendering in Vivaldi
  * Fix mobile nav obstructing content
  * Reduce footer margin only for desktop
  * Append a hash ?digest to CSS files for cache-busting
* Wed Jan 19 2022 Matej Cepl <mcepl@suse.com>
- Update to 2022.1:
  - Add a configuration for license URL.
  - Exclude the floating navbar from CHM help.
  - Make sidebar scrollable and sticky (on modern browsers)
  - Fix monospace again, on buggy Google Chrome
  - Add the copyright_url variable in the theme
  - Improve readability
  - Remove #searchbox on mobile to fix a layout bug
  - Fix the appearance of version/language selects
  - Make the theme responsive
  - Use default pygments theme
  - Test Github action to validate the theme against docsbuild scripts.
  - Add the copy button to pycon3 highlighted code blocks.
  - Updated the readme, to remind user to install the package in a virtual environment.
  - Updated the package url, using the GitHub repository instead of docs.python.org
  - Added license information to the footer of the doc
  - Fixed typo in the footer
  - Added information on how to use the package
  - Fixed code formatting
  - Fixed code bgcolor and codetextcolor for Sphinx 3.1.0+
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 2020.1
  * no upstream changelog found
* Mon Jun 10 2019 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for 2018.7 version.
